==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Pgina Anterior");
define("_NEXT","Pgina Posterior");
define("_SEARCHRESULTS","Resultados da Busca");
define("_PAGE","Pginas");
define("_RETURNTO","Voltar para");
define("_DEACTIVATE","Desativar");
define("_ACTIVATE","Ativo");
define("_ENCYCLOPEDIA","Encyclopedia");
define("_NOCONTENTFORLETTER","Sorry, there isn't any content for the letter");
define("_ENCYSELECTLETTER","Please select a letter from the following list to consult terms:");
define("_COPYRIGHT","Copyright &copy; by $sitename. All Right Reserved.");
define("_YOURADMINENCY","You're Administrator, this encyclopedia isn't active!");
define("_ENCYNOTACTIVE","Sorry, this encyclopedia isn't active right now.");
define("_AVAILABLEENCYLIST","List of available Encyclopedias in");
define("_YOURADMININACTIVELIST","You're Administrator: following is the list of Inactive Encyclopedias:");
define("_NORESULTSTEXT","No Results in Term's Text...");
define("_NORESULTSTITLE","No Results in Term's Title...");
define("_SEARCHRESULTSFOR","Search Results for:");
define("_SEARCHNOTCOMPLETE","Search options aren't complete. Please try again.");
define("_RESULTSINTERMTITLE","Results in the term's title:");
define("_RESULTSINTERMTEXT","Results in the term's text:");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Pgina Anterior");
define("_NEXT","Pgina Posterior");
define("_SEARCHRESULTS","Resultados da Busca");
define("_PAGE","Pginas");
define("_RETURNTO","Voltar para");
define("_DEACTIVATE","Desativar");
define("_ACTIVATE","Ativo");
define("_ENCYCLOPEDIA","Encyclopedia");
define("_NOCONTENTFORLETTER","Sorry, there isn't any content for the letter");
define("_ENCYSELECTLETTER","Please select a letter from the following list to consult terms:");
define("_COPYRIGHT","Copyright &copy; by $sitename. All Right Reserved.");
define("_YOURADMINENCY","You're Administrator, this encyclopedia isn't active!");
define("_ENCYNOTACTIVE","Sorry, this encyclopedia isn't active right now.");
define("_AVAILABLEENCYLIST","List of available Encyclopedias in");
define("_YOURADMININACTIVELIST","You're Administrator: following is the list of Inactive Encyclopedias:");
define("_NORESULTSTEXT","No Results in Term's Text...");
define("_NORESULTSTITLE","No Results in Term's Title...");
define("_SEARCHRESULTSFOR","Search Results for:");
define("_SEARCHNOTCOMPLETE","Search options aren't complete. Please try again.");
define("_RESULTSINTERMTITLE","Results in the term's title:");
define("_RESULTSINTERMTEXT","Results in the term's text:");

?>
